#!/bin/bash
##
## This script is a wrapper before starting the actual job.
## It will setup working and temporary directories and
## error handlers for aborting and exiting in a well-defined fashion
##

## Handle manual abort, but only when accounting is disabled
abortedByUser()
{
	if [ -n "${STATUS_FILE}" ]; then
		echo "Aborted: 1" >> ${STATUS_FILE}
	fi
	exit 137
}

## This function is executed when the script exits
cleanupOnExit()
{
	EXIT_CODE=$?
	if [ -n "${STATUS_FILE}" ]; then
		echo "Ended: `date +'%Y-%m-%d %T'`" >> ${STATUS_FILE}
		echo "ExitCode: ${EXIT_CODE}" >> ${STATUS_FILE}
	fi
	
	## Remove temporary directory unless debugging
	cd ${WD}
	if [ -z "${JOB_DEBUG}" ] && [ -d "${_tmpdir}" ]; then
		rm -rf ${_tmpdir}
	fi
}

## Register as started to $STATUS_FILE
if [ -n "${STATUS_FILE}" ]; then
	echo "Name: ${SLURM_JOB_NAME}" > ${STATUS_FILE} 
	echo "Started: `date +'%Y-%m-%d %T'`" >> ${STATUS_FILE}
	echo "NodeList: ${SLURM_JOB_NODELIST}" >> ${STATUS_FILE}
	echo "Partition: ${SLURM_JOB_PARTITION}" >> ${STATUS_FILE}

	## Add handler for catching 'kill' signals
	trap abortedByUser TERM
fi

## Add handler for cleaning up after the job has ended
trap cleanupOnExit EXIT

## Create temporary directory and ensure that it is empty
mkdir -p ${_tmpdir}
rm -rf ${_tmpdir}/*

## Finally, we can now run the actual job
cd ${WD}
srun ./job.sh
JOB_EXIT_CODE=$?

## Exit with the exit code from the job
## (not really needed in the current implementation since job.sh is the last cmd)
exit ${JOB_EXIT_CODE}
